@@ -127,21 +127,12 @@ class Scene(Geometry):
         # PointCloud objects will look like a sequence
         elif util.is_sequence(geometry):
             # if passed a sequence add all elements
-            for i, value in enumerate(geometry):
-                if i == 0:
-                    node_name = self.add_geometry(
-                        geometry=value,
-                        node_name=node_name,
-                        geom_name=geom_name,
-                        parent_node_name=parent_node_name,
-                        transform=transform)
-                else:
-                    self.add_geometry(
-                        geometry=value,
-                        geom_name=geom_name,
-                        parent_node_name=node_name)
-            return
-
+            return [self.add_geometry(
+                geometry=value,
+                node_name=node_name,
+                geom_name=geom_name,
+                parent_node_name=parent_node_name,
+                transform=transform) for value in geometry]
         elif isinstance(geometry, dict):
             # if someone passed us a dict of geometry
             for key, value in geometry.items():
